// Admin.js
import React, { useState, useEffect } from 'react';
import { useNavigate, Routes, Route, Link, useParams } from 'react-router-dom';
import './App.css';

function AdminHome() {
  const [campaigns, setCampaigns] = useState([]);

  useEffect(() => {
    fetch('http://localhost:4000/api/campaigns')
      .then((res) => res.json())
      .then((data) => setCampaigns(data))
      .catch((err) => console.error(err));
  }, []);

  return (
    <div className="container">
      <h1>Panel Administratora</h1>
      <Link to="/admin/new" className="button" style={{ marginBottom: '20px', display: 'inline-block' }}>
        Dodaj nową zbiórkę
      </Link>
      <h2>Zbiórki</h2>
      <ul>
        {campaigns.map((c) => (
          <li key={c.id} style={{ marginBottom: '10px' }}>
            <strong>{c.title}</strong> – Cel: {c.target} zł{' '}
            <Link to={`/admin/campaign/${c.id}`} className="button" style={{ marginLeft: '10px' }}>
              Zarządzaj
            </Link>
          </li>
        ))}
      </ul>
    </div>
  );
}

function NewCampaign() {
  const [title, setTitle] = useState('');
  const [description, setDescription] = useState('');
  const [target, setTarget] = useState('');
  const navigate = useNavigate();

  const handleSubmit = (e) => {
    e.preventDefault();
    const token = sessionStorage.getItem('authToken');
    fetch('http://localhost:4000/api/campaigns', {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ title, description, target: parseFloat(target), token }),
    })
      .then((res) => {
        if (!res.ok) throw new Error('Błąd tworzenia zbiórki');
        return res.json();
      })
      .then(() => {
        alert('Zbiórka dodana');
        navigate('/admin');
      })
      .catch((err) => alert('Błąd podczas dodawania zbiórki'));
  };

  return (
    <div className="container">
      <div className="card">
        <h2>Dodaj nową zbiórkę</h2>
        <form onSubmit={handleSubmit}>
          <div className="form-group">
            <label>Tytuł:</label>
            <input type="text" value={title} onChange={(e) => setTitle(e.target.value)} required />
          </div>
          <div className="form-group">
            <label>Opis:</label>
            <textarea value={description} onChange={(e) => setDescription(e.target.value)} required />
          </div>
          <div className="form-group">
            <label>Cel (zł):</label>
            <input type="number" value={target} onChange={(e) => setTarget(e.target.value)} required />
          </div>
          <button type="submit" className="button">Dodaj zbiórkę</button>
        </form>
      </div>
    </div>
  );
}

function AdminCampaignDetail() {
  const { campaignId } = useParams();
  const [campaign, setCampaign] = useState(null);
  const [donations, setDonations] = useState([]);
  const [newTarget, setNewTarget] = useState('');
  const [donationAmount, setDonationAmount] = useState('');
  const [donationDesc, setDonationDesc] = useState('');

  useEffect(() => {
    fetch(`http://localhost:4000/api/campaigns/${campaignId}`)
      .then((res) => res.json())
      .then((data) => setCampaign(data))
      .catch((err) => console.error(err));

    fetch(`http://localhost:4000/api/campaigns/${campaignId}/donations`)
      .then((res) => res.json())
      .then((data) => setDonations(data))
      .catch((err) => console.error(err));
  }, [campaignId]);

  const handleUpdateTarget = (e) => {
    e.preventDefault();
    const token = sessionStorage.getItem('authToken');
    fetch(`http://localhost:4000/api/campaigns/${campaignId}/target`, {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ newTarget: parseFloat(newTarget), token }),
    })
      .then((res) => {
        if (!res.ok) throw new Error('Błąd aktualizacji celu');
        return res.json();
      })
      .then((data) => {
        setCampaign({ ...campaign, target: data.target });
        setNewTarget('');
        alert('Cel zaktualizowany');
      })
      .catch((err) => alert('Błąd podczas aktualizacji celu'));
  };

  const handleAddDonation = (e) => {
    e.preventDefault();
    const token = sessionStorage.getItem('authToken');
    fetch(`http://localhost:4000/api/campaigns/${campaignId}/donations`, {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ amount: parseFloat(donationAmount), description: donationDesc, token }),
    })
      .then((res) => {
        if (!res.ok) throw new Error('Błąd dodawania wpłaty');
        return res.json();
      })
      .then((newDonation) => {
        setDonations([newDonation, ...donations]);
        setDonationAmount('');
        setDonationDesc('');
      })
      .catch((err) => alert('Błąd podczas dodawania wpłaty'));
  };

  if (!campaign) return <div>Ładowanie...</div>;

  return (
    <div className="container">
      <div className="card">
        <h2>Zbiórka: {campaign.title}</h2>
        <p>{campaign.description}</p>
        <p>
          Cel: <strong>{campaign.target} zł</strong> | Zebrano: <strong>{campaign.totalDonations} zł</strong>
        </p>
        <form onSubmit={handleUpdateTarget}>
          <div className="form-group">
            <label>Aktualizuj cel:</label>
            <input type="number" value={newTarget} onChange={(e) => setNewTarget(e.target.value)} required />
          </div>
          <button type="submit" className="button">Aktualizuj cel</button>
        </form>
        <h3>Dodaj wpłatę</h3>
        <form onSubmit={handleAddDonation}>
          <div className="form-group">
            <label>Kwota:</label>
            <input type="number" value={donationAmount} onChange={(e) => setDonationAmount(e.target.value)} required />
          </div>
          <div className="form-group">
            <label>Opis:</label>
            <input type="text" value={donationDesc} onChange={(e) => setDonationDesc(e.target.value)} required />
          </div>
          <button type="submit" className="button">Dodaj wpłatę</button>
        </form>
        <h3>Historia wpłat</h3>
        <ul>
          {donations.map((d) => (
            <li key={d.id}>
              Kwota: {d.amount} zł, {d.description}, {new Date(d.date).toLocaleString()}
            </li>
          ))}
        </ul>
      </div>
    </div>
  );
}

function Admin() {
  const navigate = useNavigate();

  useEffect(() => {
    const token = sessionStorage.getItem('authToken');
    if (!token) navigate('/login');
  }, [navigate]);

  return (
    <Routes>
      <Route path="/" element={<AdminHome />} />
      <Route path="/new" element={<NewCampaign />} />
      <Route path="/campaign/:campaignId" element={<AdminCampaignDetail />} />
    </Routes>
  );
}

export default Admin;
